<?php

namespace PaymentPlugins\WooCommerce\PPCP\Factories;

use PaymentPlugins\PayPalSDK\Collection;
use PaymentPlugins\PayPalSDK\Item;
use PaymentPlugins\PayPalSDK\Money;
use PaymentPlugins\WooCommerce\PPCP\Utilities\NumberUtil;

class ItemsFactory extends AbstractFactory {

	/**
	 * @param \WC_Cart $cart
	 *
	 * @return \PaymentPlugins\PayPalSDK\Collection
	 */
	public function from_cart() {
		$incl_tax = $this->display_prices_including_tax();
		$items    = new Collection();
		$totals   = 0;
		foreach ( $this->cart->get_cart() as $key => $cart_item ) {
			$total  = $incl_tax ? wc_get_price_including_tax( $cart_item['data'], [ 'qty' => $cart_item['quantity'] ] )
				: wc_get_price_excluding_tax( $cart_item['data'], [ 'qty' => 1 ] );
			$qty    = $cart_item['quantity'];
			$name   = $cart_item['data']->get_name();
			$total  = NumberUtil::round( $total );
			$totals += $total;
			$items->add( $this->get_cart_item( $total, $name, $qty, $cart_item ) );
		}
		if ( 0 < $this->cart->get_fee_total() ) {
			$items->add( $this->get_cart_item( NumberUtil::round( $this->cart->get_fee_total() ), __( 'Fees', 'pymntpl-paypal-woocommerce' ), 1, $this->currency, null ) );
		}

		return $items;
	}

	/**
	 * @return \PaymentPlugins\PayPalSDK\Collection
	 */
	public function from_order() {
		$items = new Collection();
		$total = 0;
		foreach ( $this->order->get_items() as $item ) {
			$item = $this->get_order_item( $item );
			$items->add( $item );
			$total = $total + $item->getUnitAmount()->getValue() * $item->getQuantity();
		}
		if ( 0 < $this->get_order_total_fees() ) {
			$items->add( $this->get_order_fees() );
		}

		return $items;
	}

	/**
	 * @param $total
	 * @param $name
	 * @param $qty
	 * @param $cart_item
	 *
	 * @return Item
	 */
	public function get_cart_item( $total, $name, $qty, $cart_item ) {
		return apply_filters( 'wc_ppcp_get_cart_item',
			( new Item() )->setName( $name )
			              ->setQuantity( $qty )
			              ->setUnitAmount( ( new Money() )->setCurrencyCode( $this->currency )
			                                              ->setValue( (string) $total ) ), $cart_item );
	}

	public function get_order_item( $item ) {
		return ( new Item() )->setName( $item->get_name() )
		                     ->setQuantity( $item->get_quantity() )
		                     ->setUnitAmount( ( new Money() )->setCurrencyCode( $this->currency )
		                                                     ->setValue( NumberUtil::round( $item->get_subtotal() / $item->get_quantity() ) ) );
	}

	protected function get_order_fees() {
		return ( new Item() )
			->setName( __( 'Fees', 'pymntpl-paypal-woocommerce' ) )
			->setUnitAmount( ( new Money() )->setCurrencyCode( $this->currency )->setValue( NumberUtil::round( $this->get_order_total_fees() ) ) )
			->setQuantity( 1 );
	}

}